@@ -1,5 +1,5 @@
 use proc_macro2::Ident;
-use syn::{AngleBracketedGenericArguments, Expr};
+use syn::{AngleBracketedGenericArguments, Visibility, Attribute};
 
 #[derive(Clone)]
 /// Contains all data for the states
@@ -18,6 +18,8 @@ pub struct Transition {
 
 // Contains all data required to generate the state machine
 pub struct Machine {
+    pub attributes: Vec<Attribute>,
+    pub visibility: Option<Visibility>,
     pub name: Ident,
     pub init: State,
     pub states: Vec<State>,
@@ -36,8 +38,28 @@ pub struct MatchStateEntry {
     pub var_name: Ident,
 }
 
-// Contains data needed check if the current state is active
-pub struct IsState {
-    pub state: Expr,
-    pub state_entry: StateEntry,
+// The actual message containing the struct name and optional generics arguments
+pub struct Message {
+    pub generics: Option<AngleBracketedGenericArguments>,
+    pub name: Ident,
 }
+
+// Enum containing the direction of the message. Can be either a push or poll message
+pub enum MessageDir {
+    Push(Message),
+    Poll(Message),
+}
+
+// Contains the target state plus all message information used to generate the necessary trait
+// implementations
+pub struct StateMessage {
+    pub state: State,
+    pub message: MessageDir,
+}
+
+// The whole message that will be used to generate the macro outputs
+pub struct Messages {
+    pub name: Ident,
+    pub enum_name: Ident,
+    pub messages: Vec<StateMessage>,
+}
\ No newline at end of file
